@@ -141,6 +141,9 @@ class CrudBase:
             elif operator == 'gq':
                 num_rows_deleted = self.session.query(self.orm_model).filter(getattr(self.orm_model, field) >= value) \
                     .delete()
+            elif operator == 'lq':
+                num_rows_deleted = self.session.query(self.orm_model).filter(getattr(self.orm_model, field) <= value) \
+                    .delete()
             else:
                 assert False, "operator not supported"
             self.session.commit()
